==> github_custom_actions-2.0.0.tar.gz: github_custom_actions-2.0.0/docs/src/ru/index.md <==
# github-custom-actions

Библиотека упрощающая создание
[custom GitHub Actions](https://docs.github.com/en/actions/creating-actions/about-custom-actions).

Может работать даже с Python 3.7 чтобы поддерживать древние self-hosted action runners.

### Быстрый старт

```python
--8<-- "quick_start.py"
```

Этот пример использует переменную `runner_os` из переменных окружения GitHub. 

Все переменные из окружения GitHub доступны в `env`, 
описания которых отображаются в вашей IDE при наведении мыши:
![var_ide_hover_docstring.jpg](images/var_ide_hover_docstring.jpg)

Action получает значение из action input `my-input` и отображает его 
в `step summary` на странице билда GitHub.

Оно также возвращает значение в action output `runner-os`.

Основной блок запускает метод `main()` действия с необходимым кодом для перехвата и обработки исключений.

### Явно определенные входы и выходы

С явно определенными входами и выходами вы можете использовать автодополнение кода с проверкой на опечатки:

```python
--8<-- "input_output_typed.py"
```

Обратите внимание, что вы только определяете типы входов и выходов, а экземпляры этих классов создаются автоматически
при инициализации `MyAction`.

Теперь вы можете использовать атрибуты, определенные в классах `inputs` и `outputs` действия. 
Все имена атрибутов преобразуются в `kebab-case`, что позволяет использовать точечную нотацию, например `inputs.my_input`, 
вместо `inputs['my-input']`.

Если вы определили input как `Path`, он будет преобразован в объект `Path`.

При желании вы все также можете использовать стиль `inputs['my-input']`.

### Пример использования

[Allure Test Report Action](https://github.com/andgineer/allure-report/blob/main/src/allure_generate.py)

==> github_custom_actions-2.1.0.tar.gz: github_custom_actions-2.1.0/docs/src/ru/index.md <==
# github-custom-actions

Библиотека упрощающая создание
[custom GitHub Actions](https://docs.github.com/en/actions/creating-actions/about-custom-actions).

Может работать даже с Python 3.7 чтобы поддерживать древние self-hosted action runners.

### Быстрый старт

```python
--8<-- "quick_start.py"
```

Этот пример использует переменную [runner_os][github_custom_actions.GithubVars.runner_os] из 
[переменных окружения GitHub][runner_os][github_custom_actions.GithubVars]. 

Все переменные из окружения GitHub доступны в `env`, 
описания которых отображаются в вашей IDE при наведении мыши:
![var_ide_hover_docstring.jpg](images/var_ide_hover_docstring.jpg)

Action получает значение из [action input](inputs) `my-input` и отображает его 
в [step summary](summary) на странице билда GitHub.

Оно также возвращает значение в [action output](outputs) `runner-os`.

`run()` в основном блоке запускает метод [main()](main) реализующий вашу Github action.

### Явно определенные входы и выходы

С явно определенными входами и выходами вы можете использовать автодополнение кода с проверкой на опечатки:

```python
--8<-- "input_output_typed.py"
```

Обратите внимание, что вы только определяете типы входов и выходов, а экземпляры этих классов создаются автоматически
при инициализации [ActionBase](base).

Теперь вы можете использовать атрибуты, определенные в классах `inputs` и `outputs` действия. 
Все имена атрибутов преобразуются в `kebab-case`, что позволяет использовать точечную нотацию, например `inputs.my_input`, 
вместо `inputs['my-input']`.

Если вы определили input как `Path`, он будет преобразован в объект `Path`.

При желании вы все также можете использовать стиль `inputs['my-input']`.

### Пример использования

[Allure Test Report Action](https://github.com/andgineer/allure-report/blob/main/src/allure_generate.py)
